/* testreadonlybidirlist.c generated by valac 0.56.3, the Vala compiler
 * generated from testreadonlybidirlist.vala, do not modify */

/* testreadonlybidirlist.vala
 *
 * Copyright (C) 2011  Maciej Piechotka
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Maciej Piechotka <uzytkownik2@gmail.com>
 */

#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GEE_TYPE_TEST_CASE (gee_test_case_get_type ())
#define GEE_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_TEST_CASE, GeeTestCase))
#define GEE_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_TEST_CASE, GeeTestCaseClass))
#define GEE_IS_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_TEST_CASE))
#define GEE_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_TEST_CASE))
#define GEE_TEST_CASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_TEST_CASE, GeeTestCaseClass))

typedef struct _GeeTestCase GeeTestCase;
typedef struct _GeeTestCaseClass GeeTestCaseClass;
typedef struct _GeeTestCasePrivate GeeTestCasePrivate;

#define TYPE_READ_ONLY_COLLECTION_TESTS (read_only_collection_tests_get_type ())
#define READ_ONLY_COLLECTION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_READ_ONLY_COLLECTION_TESTS, ReadOnlyCollectionTests))
#define READ_ONLY_COLLECTION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_READ_ONLY_COLLECTION_TESTS, ReadOnlyCollectionTestsClass))
#define IS_READ_ONLY_COLLECTION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_READ_ONLY_COLLECTION_TESTS))
#define IS_READ_ONLY_COLLECTION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_READ_ONLY_COLLECTION_TESTS))
#define READ_ONLY_COLLECTION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_READ_ONLY_COLLECTION_TESTS, ReadOnlyCollectionTestsClass))

typedef struct _ReadOnlyCollectionTests ReadOnlyCollectionTests;
typedef struct _ReadOnlyCollectionTestsClass ReadOnlyCollectionTestsClass;
typedef struct _ReadOnlyCollectionTestsPrivate ReadOnlyCollectionTestsPrivate;

#define TYPE_READ_ONLY_LIST_TESTS (read_only_list_tests_get_type ())
#define READ_ONLY_LIST_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_READ_ONLY_LIST_TESTS, ReadOnlyListTests))
#define READ_ONLY_LIST_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_READ_ONLY_LIST_TESTS, ReadOnlyListTestsClass))
#define IS_READ_ONLY_LIST_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_READ_ONLY_LIST_TESTS))
#define IS_READ_ONLY_LIST_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_READ_ONLY_LIST_TESTS))
#define READ_ONLY_LIST_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_READ_ONLY_LIST_TESTS, ReadOnlyListTestsClass))

typedef struct _ReadOnlyListTests ReadOnlyListTests;
typedef struct _ReadOnlyListTestsClass ReadOnlyListTestsClass;
typedef struct _ReadOnlyListTestsPrivate ReadOnlyListTestsPrivate;

#define TYPE_READ_ONLY_BIDIR_LIST_TESTS (read_only_bidir_list_tests_get_type ())
#define READ_ONLY_BIDIR_LIST_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_READ_ONLY_BIDIR_LIST_TESTS, ReadOnlyBidirListTests))
#define READ_ONLY_BIDIR_LIST_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_READ_ONLY_BIDIR_LIST_TESTS, ReadOnlyBidirListTestsClass))
#define IS_READ_ONLY_BIDIR_LIST_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_READ_ONLY_BIDIR_LIST_TESTS))
#define IS_READ_ONLY_BIDIR_LIST_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_READ_ONLY_BIDIR_LIST_TESTS))
#define READ_ONLY_BIDIR_LIST_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_READ_ONLY_BIDIR_LIST_TESTS, ReadOnlyBidirListTestsClass))

typedef struct _ReadOnlyBidirListTests ReadOnlyBidirListTests;
typedef struct _ReadOnlyBidirListTestsClass ReadOnlyBidirListTestsClass;
typedef struct _ReadOnlyBidirListTestsPrivate ReadOnlyBidirListTestsPrivate;
enum  {
	READ_ONLY_BIDIR_LIST_TESTS_0_PROPERTY,
	READ_ONLY_BIDIR_LIST_TESTS_NUM_PROPERTIES
};
static GParamSpec* read_only_bidir_list_tests_properties[READ_ONLY_BIDIR_LIST_TESTS_NUM_PROPERTIES];
typedef void (*GeeTestCaseTestMethod) (gpointer user_data);
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GeeTestCase {
	GObject parent_instance;
	GeeTestCasePrivate * priv;
};

struct _GeeTestCaseClass {
	GObjectClass parent_class;
	void (*set_up) (GeeTestCase* self);
	void (*tear_down) (GeeTestCase* self);
};

struct _ReadOnlyCollectionTests {
	GeeTestCase parent_instance;
	ReadOnlyCollectionTestsPrivate * priv;
	GeeCollection* test_collection;
	GeeCollection* ro_collection;
};

struct _ReadOnlyCollectionTestsClass {
	GeeTestCaseClass parent_class;
	GeeCollection* (*get_ro_view) (ReadOnlyCollectionTests* self, GeeCollection* collection);
};

struct _ReadOnlyListTests {
	ReadOnlyCollectionTests parent_instance;
	ReadOnlyListTestsPrivate * priv;
};

struct _ReadOnlyListTestsClass {
	ReadOnlyCollectionTestsClass parent_class;
};

struct _ReadOnlyBidirListTests {
	ReadOnlyListTests parent_instance;
	ReadOnlyBidirListTestsPrivate * priv;
};

struct _ReadOnlyBidirListTestsClass {
	ReadOnlyListTestsClass parent_class;
};

static gpointer read_only_bidir_list_tests_parent_class = NULL;

VALA_EXTERN GType gee_test_case_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GeeTestCase, g_object_unref)
VALA_EXTERN GType read_only_collection_tests_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ReadOnlyCollectionTests, g_object_unref)
VALA_EXTERN GType read_only_list_tests_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ReadOnlyListTests, g_object_unref)
VALA_EXTERN GType read_only_bidir_list_tests_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ReadOnlyBidirListTests, g_object_unref)
VALA_EXTERN GeeCollection* read_only_collection_tests_get_ro_view (ReadOnlyCollectionTests* self,
                                                       GeeCollection* collection);
VALA_EXTERN ReadOnlyBidirListTests* read_only_bidir_list_tests_new (void);
VALA_EXTERN ReadOnlyBidirListTests* read_only_bidir_list_tests_construct (GType object_type);
VALA_EXTERN ReadOnlyListTests* read_only_list_tests_new_with_name (const gchar* name);
VALA_EXTERN ReadOnlyListTests* read_only_list_tests_construct_with_name (GType object_type,
                                                             const gchar* name);
VALA_EXTERN void gee_test_case_add_test (GeeTestCase* self,
                             const gchar* name,
                             GeeTestCaseTestMethod test,
                             gpointer test_target,
                             GDestroyNotify test_target_destroy_notify);
VALA_EXTERN void read_only_bidir_list_tests_test_immutable_iterator (ReadOnlyBidirListTests* self);
static void _read_only_bidir_list_tests_test_immutable_iterator_gee_test_case_test_method (gpointer self);
static GeeCollection* read_only_bidir_list_tests_real_get_ro_view (ReadOnlyCollectionTests* base,
                                                            GeeCollection* collection);
static GType read_only_bidir_list_tests_get_type_once (void);

static void
_read_only_bidir_list_tests_test_immutable_iterator_gee_test_case_test_method (gpointer self)
{
	read_only_bidir_list_tests_test_immutable_iterator ((ReadOnlyBidirListTests*) self);
}

ReadOnlyBidirListTests*
read_only_bidir_list_tests_construct (GType object_type)
{
	ReadOnlyBidirListTests * self = NULL;
	self = (ReadOnlyBidirListTests*) read_only_list_tests_construct_with_name (object_type, "ReadOnlyBidirList");
	gee_test_case_add_test ((GeeTestCase*) self, "[ReadOnlyBidirList] immutable iterator", _read_only_bidir_list_tests_test_immutable_iterator_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	return self;
}

ReadOnlyBidirListTests*
read_only_bidir_list_tests_new (void)
{
	return read_only_bidir_list_tests_construct (TYPE_READ_ONLY_BIDIR_LIST_TESTS);
}

static GeeCollection*
read_only_bidir_list_tests_real_get_ro_view (ReadOnlyCollectionTests* base,
                                             GeeCollection* collection)
{
	ReadOnlyBidirListTests * self;
	GeeBidirList* _tmp0_;
	GeeBidirList* _tmp1_;
	GeeCollection* result;
	self = (ReadOnlyBidirListTests*) base;
	g_return_val_if_fail (collection != NULL, NULL);
	_tmp0_ = gee_bidir_list_get_read_only_view (G_TYPE_CHECK_INSTANCE_CAST (collection, GEE_TYPE_BIDIR_LIST, GeeBidirList));
	_tmp1_ = _tmp0_;
	result = (GeeCollection*) _tmp1_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
read_only_bidir_list_tests_test_immutable_iterator (ReadOnlyBidirListTests* self)
{
	GeeBidirList* test_list = NULL;
	GeeCollection* _tmp0_;
	GeeBidirList* _tmp1_;
	GeeBidirList* ro_list = NULL;
	GeeCollection* _tmp2_;
	GeeBidirList* _tmp3_;
	GeeBidirList* _tmp4_;
	GeeBidirList* _tmp5_;
	GeeBidirList* _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	GeeBidirList* _tmp9_;
	gpointer _tmp10_;
	gchar* _tmp11_;
	GeeBidirList* _tmp12_;
	gpointer _tmp13_;
	gchar* _tmp14_;
	GeeBidirListIterator* iterator = NULL;
	GeeBidirList* _tmp15_;
	GeeBidirListIterator* _tmp16_;
	GeeBidirListIterator* _tmp17_;
	GeeBidirListIterator* _tmp18_;
	GeeBidirListIterator* _tmp19_;
	gpointer _tmp20_;
	gchar* _tmp21_;
	GeeBidirListIterator* _tmp22_;
	GeeBidirListIterator* _tmp23_;
	GeeBidirListIterator* _tmp24_;
	GeeBidirListIterator* _tmp25_;
	gpointer _tmp26_;
	gchar* _tmp27_;
	GeeBidirListIterator* _tmp28_;
	GeeBidirListIterator* _tmp29_;
	GeeBidirListIterator* _tmp30_;
	GeeBidirListIterator* _tmp31_;
	GeeBidirListIterator* _tmp32_;
	GeeBidirListIterator* _tmp33_;
	gpointer _tmp34_;
	gchar* _tmp35_;
	GeeBidirListIterator* _tmp36_;
	GeeBidirListIterator* _tmp37_;
	GeeBidirListIterator* _tmp38_;
	gpointer _tmp39_;
	gchar* _tmp40_;
	GeeBidirListIterator* _tmp41_;
	GeeBidirListIterator* _tmp42_;
	GeeBidirListIterator* _tmp43_;
	gpointer _tmp44_;
	gchar* _tmp45_;
	GeeBidirListIterator* _tmp46_;
	GeeBidirList* _tmp48_;
	gint _tmp49_;
	gint _tmp50_;
	GeeBidirList* _tmp51_;
	gpointer _tmp52_;
	gchar* _tmp53_;
	GeeBidirList* _tmp54_;
	gpointer _tmp55_;
	gchar* _tmp56_;
	GeeBidirListIterator* _tmp57_;
	GeeBidirList* _tmp59_;
	gint _tmp60_;
	gint _tmp61_;
	GeeBidirList* _tmp62_;
	gpointer _tmp63_;
	gchar* _tmp64_;
	GeeBidirList* _tmp65_;
	gpointer _tmp66_;
	gchar* _tmp67_;
	GeeBidirListIterator* _tmp68_;
	GeeBidirList* _tmp70_;
	gint _tmp71_;
	gint _tmp72_;
	GeeBidirList* _tmp73_;
	gpointer _tmp74_;
	gchar* _tmp75_;
	GeeBidirList* _tmp76_;
	gpointer _tmp77_;
	gchar* _tmp78_;
	GeeBidirListIterator* _tmp79_;
	GeeBidirList* _tmp81_;
	gint _tmp82_;
	gint _tmp83_;
	GeeBidirList* _tmp84_;
	gpointer _tmp85_;
	gchar* _tmp86_;
	GeeBidirList* _tmp87_;
	gpointer _tmp88_;
	gchar* _tmp89_;
	GeeBidirListIterator* _tmp90_;
	g_return_if_fail (self != NULL);
	_tmp0_ = ((ReadOnlyCollectionTests*) self)->test_collection;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GEE_TYPE_BIDIR_LIST) ? ((GeeBidirList*) _tmp0_) : NULL);
	test_list = _tmp1_;
	_tmp2_ = ((ReadOnlyCollectionTests*) self)->ro_collection;
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GEE_TYPE_BIDIR_LIST) ? ((GeeBidirList*) _tmp2_) : NULL);
	ro_list = _tmp3_;
	_tmp4_ = test_list;
	_vala_assert (gee_collection_add ((GeeCollection*) _tmp4_, "one"), "test_list.add (\"one\")");
	_tmp5_ = test_list;
	_vala_assert (gee_collection_add ((GeeCollection*) _tmp5_, "two"), "test_list.add (\"two\")");
	_tmp6_ = ro_list;
	_tmp7_ = gee_collection_get_size ((GeeCollection*) _tmp6_);
	_tmp8_ = _tmp7_;
	_vala_assert (_tmp8_ == 2, "ro_list.size == 2");
	_tmp9_ = ro_list;
	_tmp10_ = gee_list_get ((GeeList*) _tmp9_, 0);
	_tmp11_ = (gchar*) _tmp10_;
	_vala_assert (g_strcmp0 (_tmp11_, "one") == 0, "ro_list.get (0) == \"one\"");
	_g_free0 (_tmp11_);
	_tmp12_ = ro_list;
	_tmp13_ = gee_list_get ((GeeList*) _tmp12_, 1);
	_tmp14_ = (gchar*) _tmp13_;
	_vala_assert (g_strcmp0 (_tmp14_, "two") == 0, "ro_list.get (1) == \"two\"");
	_g_free0 (_tmp14_);
	_tmp15_ = ro_list;
	_tmp16_ = gee_bidir_list_bidir_list_iterator (_tmp15_);
	iterator = _tmp16_;
	_tmp17_ = iterator;
	_vala_assert (gee_iterator_has_next ((GeeIterator*) _tmp17_), "iterator.has_next ()");
	_tmp18_ = iterator;
	_vala_assert (gee_iterator_next ((GeeIterator*) _tmp18_), "iterator.next ()");
	_tmp19_ = iterator;
	_tmp20_ = gee_iterator_get ((GeeIterator*) _tmp19_);
	_tmp21_ = (gchar*) _tmp20_;
	_vala_assert (g_strcmp0 (_tmp21_, "one") == 0, "iterator.get () == \"one\"");
	_g_free0 (_tmp21_);
	_tmp22_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp22_) == 0, "iterator.index () == 0");
	_tmp23_ = iterator;
	_vala_assert (gee_iterator_has_next ((GeeIterator*) _tmp23_), "iterator.has_next ()");
	_tmp24_ = iterator;
	_vala_assert (gee_iterator_next ((GeeIterator*) _tmp24_), "iterator.next ()");
	_tmp25_ = iterator;
	_tmp26_ = gee_iterator_get ((GeeIterator*) _tmp25_);
	_tmp27_ = (gchar*) _tmp26_;
	_vala_assert (g_strcmp0 (_tmp27_, "two") == 0, "iterator.get () == \"two\"");
	_g_free0 (_tmp27_);
	_tmp28_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp28_) == 1, "iterator.index () == 1");
	_tmp29_ = iterator;
	_vala_assert (!gee_iterator_has_next ((GeeIterator*) _tmp29_), "! iterator.has_next ()");
	_tmp30_ = iterator;
	_vala_assert (!gee_iterator_next ((GeeIterator*) _tmp30_), "! iterator.next ()");
	_tmp31_ = iterator;
	_vala_assert (gee_bidir_iterator_has_previous ((GeeBidirIterator*) _tmp31_), "iterator.has_previous ()");
	_tmp32_ = iterator;
	_vala_assert (gee_bidir_iterator_previous ((GeeBidirIterator*) _tmp32_), "iterator.previous ()");
	_tmp33_ = iterator;
	_tmp34_ = gee_iterator_get ((GeeIterator*) _tmp33_);
	_tmp35_ = (gchar*) _tmp34_;
	_vala_assert (g_strcmp0 (_tmp35_, "one") == 0, "iterator.get () == \"one\"");
	_g_free0 (_tmp35_);
	_tmp36_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp36_) == 0, "iterator.index () == 0");
	_tmp37_ = iterator;
	_vala_assert (gee_bidir_iterator_last ((GeeBidirIterator*) _tmp37_), "iterator.last ()");
	_tmp38_ = iterator;
	_tmp39_ = gee_iterator_get ((GeeIterator*) _tmp38_);
	_tmp40_ = (gchar*) _tmp39_;
	_vala_assert (g_strcmp0 (_tmp40_, "two") == 0, "iterator.get () == \"two\"");
	_g_free0 (_tmp40_);
	_tmp41_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp41_) == 1, "iterator.index () == 1");
	_tmp42_ = iterator;
	_vala_assert (gee_bidir_iterator_first ((GeeBidirIterator*) _tmp42_), "iterator.first ()");
	_tmp43_ = iterator;
	_tmp44_ = gee_iterator_get ((GeeIterator*) _tmp43_);
	_tmp45_ = (gchar*) _tmp44_;
	_vala_assert (g_strcmp0 (_tmp45_, "one") == 0, "iterator.get () == \"one\"");
	_g_free0 (_tmp45_);
	_tmp46_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp46_) == 0, "iterator.index () == 0");
	if (g_test_trap_fork ((guint64) 0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
		GeeBidirListIterator* _tmp47_;
		_tmp47_ = iterator;
		gee_iterator_remove ((GeeIterator*) _tmp47_);
		exit (0);
	}
	g_test_trap_assert_failed ();
	_tmp48_ = ro_list;
	_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
	_tmp50_ = _tmp49_;
	_vala_assert (_tmp50_ == 2, "ro_list.size == 2");
	_tmp51_ = ro_list;
	_tmp52_ = gee_list_get ((GeeList*) _tmp51_, 0);
	_tmp53_ = (gchar*) _tmp52_;
	_vala_assert (g_strcmp0 (_tmp53_, "one") == 0, "ro_list.get (0) == \"one\"");
	_g_free0 (_tmp53_);
	_tmp54_ = ro_list;
	_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 1);
	_tmp56_ = (gchar*) _tmp55_;
	_vala_assert (g_strcmp0 (_tmp56_, "two") == 0, "ro_list.get (1) == \"two\"");
	_g_free0 (_tmp56_);
	_tmp57_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp57_) == 0, "iterator.index () == 0");
	if (g_test_trap_fork ((guint64) 0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
		GeeBidirListIterator* _tmp58_;
		_tmp58_ = iterator;
		g_object_set ((GObject*) _tmp58_, "three", NULL);
		exit (0);
	}
	g_test_trap_assert_failed ();
	_tmp59_ = ro_list;
	_tmp60_ = gee_collection_get_size ((GeeCollection*) _tmp59_);
	_tmp61_ = _tmp60_;
	_vala_assert (_tmp61_ == 2, "ro_list.size == 2");
	_tmp62_ = ro_list;
	_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 0);
	_tmp64_ = (gchar*) _tmp63_;
	_vala_assert (g_strcmp0 (_tmp64_, "one") == 0, "ro_list.get (0) == \"one\"");
	_g_free0 (_tmp64_);
	_tmp65_ = ro_list;
	_tmp66_ = gee_list_get ((GeeList*) _tmp65_, 1);
	_tmp67_ = (gchar*) _tmp66_;
	_vala_assert (g_strcmp0 (_tmp67_, "two") == 0, "ro_list.get (1) == \"two\"");
	_g_free0 (_tmp67_);
	_tmp68_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp68_) == 0, "iterator.index () == 0");
	if (g_test_trap_fork ((guint64) 0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
		GeeBidirListIterator* _tmp69_;
		_tmp69_ = iterator;
		gee_bidir_list_iterator_insert (_tmp69_, "three");
		exit (0);
	}
	g_test_trap_assert_failed ();
	_tmp70_ = ro_list;
	_tmp71_ = gee_collection_get_size ((GeeCollection*) _tmp70_);
	_tmp72_ = _tmp71_;
	_vala_assert (_tmp72_ == 2, "ro_list.size == 2");
	_tmp73_ = ro_list;
	_tmp74_ = gee_list_get ((GeeList*) _tmp73_, 0);
	_tmp75_ = (gchar*) _tmp74_;
	_vala_assert (g_strcmp0 (_tmp75_, "one") == 0, "ro_list.get (0) == \"one\"");
	_g_free0 (_tmp75_);
	_tmp76_ = ro_list;
	_tmp77_ = gee_list_get ((GeeList*) _tmp76_, 1);
	_tmp78_ = (gchar*) _tmp77_;
	_vala_assert (g_strcmp0 (_tmp78_, "two") == 0, "ro_list.get (1) == \"two\"");
	_g_free0 (_tmp78_);
	_tmp79_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp79_) == 0, "iterator.index () == 0");
	if (g_test_trap_fork ((guint64) 0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
		GeeBidirListIterator* _tmp80_;
		_tmp80_ = iterator;
		gee_list_iterator_add ((GeeListIterator*) _tmp80_, "three");
		exit (0);
	}
	g_test_trap_assert_failed ();
	_tmp81_ = ro_list;
	_tmp82_ = gee_collection_get_size ((GeeCollection*) _tmp81_);
	_tmp83_ = _tmp82_;
	_vala_assert (_tmp83_ == 2, "ro_list.size == 2");
	_tmp84_ = ro_list;
	_tmp85_ = gee_list_get ((GeeList*) _tmp84_, 0);
	_tmp86_ = (gchar*) _tmp85_;
	_vala_assert (g_strcmp0 (_tmp86_, "one") == 0, "ro_list.get (0) == \"one\"");
	_g_free0 (_tmp86_);
	_tmp87_ = ro_list;
	_tmp88_ = gee_list_get ((GeeList*) _tmp87_, 1);
	_tmp89_ = (gchar*) _tmp88_;
	_vala_assert (g_strcmp0 (_tmp89_, "two") == 0, "ro_list.get (1) == \"two\"");
	_g_free0 (_tmp89_);
	_tmp90_ = iterator;
	_vala_assert (gee_list_iterator_index ((GeeListIterator*) _tmp90_) == 0, "iterator.index () == 0");
	_g_object_unref0 (iterator);
	_g_object_unref0 (ro_list);
	_g_object_unref0 (test_list);
}

static void
read_only_bidir_list_tests_class_init (ReadOnlyBidirListTestsClass * klass,
                                       gpointer klass_data)
{
	read_only_bidir_list_tests_parent_class = g_type_class_peek_parent (klass);
	((ReadOnlyCollectionTestsClass *) klass)->get_ro_view = (GeeCollection* (*) (ReadOnlyCollectionTests*, GeeCollection*)) read_only_bidir_list_tests_real_get_ro_view;
}

static void
read_only_bidir_list_tests_instance_init (ReadOnlyBidirListTests * self,
                                          gpointer klass)
{
}

static GType
read_only_bidir_list_tests_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ReadOnlyBidirListTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) read_only_bidir_list_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ReadOnlyBidirListTests), 0, (GInstanceInitFunc) read_only_bidir_list_tests_instance_init, NULL };
	GType read_only_bidir_list_tests_type_id;
	read_only_bidir_list_tests_type_id = g_type_register_static (TYPE_READ_ONLY_LIST_TESTS, "ReadOnlyBidirListTests", &g_define_type_info, 0);
	return read_only_bidir_list_tests_type_id;
}

GType
read_only_bidir_list_tests_get_type (void)
{
	static volatile gsize read_only_bidir_list_tests_type_id__once = 0;
	if (g_once_init_enter (&read_only_bidir_list_tests_type_id__once)) {
		GType read_only_bidir_list_tests_type_id;
		read_only_bidir_list_tests_type_id = read_only_bidir_list_tests_get_type_once ();
		g_once_init_leave (&read_only_bidir_list_tests_type_id__once, read_only_bidir_list_tests_type_id);
	}
	return read_only_bidir_list_tests_type_id__once;
}

